==> MLTSA-0.0.3.tar.gz: MLTSA-0.0.3/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys
sys.path.insert(0, os.path.abspath('../../MLTSA_examples'))
sys.path.insert(0, os.path.abspath('../../MLTSA_examples/OneD_pot'))
sys.path.insert(0, os.path.abspath('../../MLTSA_sklearn'))
sys.path.insert(0, os.path.abspath('../../MLTSA_tensorflow'))


# -- Project information -----------------------------------------------------

project = 'MLTSA'
copyright = '2021, Pedro Buigues, Edina Rosta'
author = 'Pedro Buigues, Edina Rosta'

# The full version, including alpha/beta/rc tags
release = '0.0.2'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.autosummary', "nbsphinx"
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "_templates", "_examples"]

source_suffix = ['.rst', '.md']

autosummary_generate = True  # Turn on sphinx.ext.autosummary

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

==> MLTSA-0.0.5.tar.gz: MLTSA-0.0.5/docs/source/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys
sys.path.insert(0, os.path.abspath('../../MLTSA_datasets'))
sys.path.insert(0, os.path.abspath('../../MLTSA_datasets/OneD_pot'))
sys.path.insert(0, os.path.abspath('../../MLTSA_sklearn'))
sys.path.insert(0, os.path.abspath('../../MLTSA_tensorflow'))
sys.path.insert(0, os.path.abspath('../../MLTSA_datasets/MD_DATA'))
sys.path.insert(0, os.path.abspath('../../MLTSA_datasets/MD_RUN'))
sys.path.insert(0, os.path.abspath('../../notebooks'))


# -- Project information -----------------------------------------------------

project = 'MLTSA'
copyright = '2021, Pedro Buigues, Edina Rosta'
author = 'Pedro Buigues, Edina Rosta'

# The full version, including alpha/beta/rc tags
release = '0.0.4'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.autosummary', "nbsphinx"
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "_templates", "_examples"]

source_suffix = ['.rst', '.md']

autosummary_generate = True  # Turn on sphinx.ext.autosummary

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']
